aboutsummaryrefslogtreecommitdiffstats
path: root/bindings/cpp/include
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2021-05-25 12:07:17 -0400
committerDavid Robillard <d@drobilla.net>2021-05-25 12:12:59 -0400
commite6183b3dbe6b83d642cad1dfb296083ce8c53360 (patch)
tree60ec2f11586489bcd81364654d6964d399484596 /bindings/cpp/include
parent040e94b26395451b78f5cbe0b7f208afcf28af1b (diff)
downloadpugl-e6183b3dbe6b83d642cad1dfb296083ce8c53360.tar.gz
pugl-e6183b3dbe6b83d642cad1dfb296083ce8c53360.tar.bz2
pugl-e6183b3dbe6b83d642cad1dfb296083ce8c53360.zip
Rename event structs in a more readable style
Aside from reading more naturally, this avoids clashes with types that are not events, like PuglEventFlags. This is also more consistent with the C++ bindings, where "EventExpose" would be quite strange, for example. Apologies for the noise. Aliases to the old names will be preserved in the deprecated API like other things for a short while.
Diffstat (limited to 'bindings/cpp/include')
-rw-r--r--bindings/cpp/include/pugl/pugl.hpp92
1 files changed, 46 insertions, 46 deletions
diff --git a/bindings/cpp/include/pugl/pugl.hpp b/bindings/cpp/include/pugl/pugl.hpp
index 4eebdac..69ea0eb 100644
--- a/bindings/cpp/include/pugl/pugl.hpp
+++ b/bindings/cpp/include/pugl/pugl.hpp
@@ -117,74 +117,74 @@ using EventFlag = PuglEventFlag; ///< @copydoc PuglEventFlag
using EventFlags = PuglEventFlags; ///< @copydoc PuglEventFlags
using CrossingMode = PuglCrossingMode; ///< @copydoc PuglCrossingMode
-/// @copydoc PuglEventCreate
-using CreateEvent = Event<PUGL_CREATE, PuglEventCreate>;
+/// @copydoc PuglCreateEvent
+using CreateEvent = Event<PUGL_CREATE, PuglCreateEvent>;
-/// @copydoc PuglEventDestroy
-using DestroyEvent = Event<PUGL_DESTROY, PuglEventDestroy>;
+/// @copydoc PuglDestroyEvent
+using DestroyEvent = Event<PUGL_DESTROY, PuglDestroyEvent>;
-/// @copydoc PuglEventConfigure
-using ConfigureEvent = Event<PUGL_CONFIGURE, PuglEventConfigure>;
+/// @copydoc PuglConfigureEvent
+using ConfigureEvent = Event<PUGL_CONFIGURE, PuglConfigureEvent>;
-/// @copydoc PuglEventMap
-using MapEvent = Event<PUGL_MAP, PuglEventMap>;
+/// @copydoc PuglMapEvent
+using MapEvent = Event<PUGL_MAP, PuglMapEvent>;
-/// @copydoc PuglEventUnmap
-using UnmapEvent = Event<PUGL_UNMAP, PuglEventUnmap>;
+/// @copydoc PuglUnmapEvent
+using UnmapEvent = Event<PUGL_UNMAP, PuglUnmapEvent>;
-/// @copydoc PuglEventUpdate
-using UpdateEvent = Event<PUGL_UPDATE, PuglEventUpdate>;
+/// @copydoc PuglUpdateEvent
+using UpdateEvent = Event<PUGL_UPDATE, PuglUpdateEvent>;
-/// @copydoc PuglEventExpose
-using ExposeEvent = Event<PUGL_EXPOSE, PuglEventExpose>;
+/// @copydoc PuglExposeEvent
+using ExposeEvent = Event<PUGL_EXPOSE, PuglExposeEvent>;
-/// @copydoc PuglEventClose
-using CloseEvent = Event<PUGL_CLOSE, PuglEventClose>;
+/// @copydoc PuglCloseEvent
+using CloseEvent = Event<PUGL_CLOSE, PuglCloseEvent>;
-/// @copydoc PuglEventFocus
-using FocusInEvent = Event<PUGL_FOCUS_IN, PuglEventFocus>;
+/// @copydoc PuglFocusEvent
+using FocusInEvent = Event<PUGL_FOCUS_IN, PuglFocusEvent>;
-/// @copydoc PuglEventFocus
-using FocusOutEvent = Event<PUGL_FOCUS_OUT, PuglEventFocus>;
+/// @copydoc PuglFocusEvent
+using FocusOutEvent = Event<PUGL_FOCUS_OUT, PuglFocusEvent>;
-/// @copydoc PuglEventKey
-using KeyPressEvent = Event<PUGL_KEY_PRESS, PuglEventKey>;
+/// @copydoc PuglKeyEvent
+using KeyPressEvent = Event<PUGL_KEY_PRESS, PuglKeyEvent>;
-/// @copydoc PuglEventKey
-using KeyReleaseEvent = Event<PUGL_KEY_RELEASE, PuglEventKey>;
+/// @copydoc PuglKeyEvent
+using KeyReleaseEvent = Event<PUGL_KEY_RELEASE, PuglKeyEvent>;
-/// @copydoc PuglEventText
-using TextEvent = Event<PUGL_TEXT, PuglEventText>;
+/// @copydoc PuglTextEvent
+using TextEvent = Event<PUGL_TEXT, PuglTextEvent>;
-/// @copydoc PuglEventCrossing
-using PointerInEvent = Event<PUGL_POINTER_IN, PuglEventCrossing>;
+/// @copydoc PuglCrossingEvent
+using PointerInEvent = Event<PUGL_POINTER_IN, PuglCrossingEvent>;
-/// @copydoc PuglEventCrossing
-using PointerOutEvent = Event<PUGL_POINTER_OUT, PuglEventCrossing>;
+/// @copydoc PuglCrossingEvent
+using PointerOutEvent = Event<PUGL_POINTER_OUT, PuglCrossingEvent>;
-/// @copydoc PuglEventButton
-using ButtonPressEvent = Event<PUGL_BUTTON_PRESS, PuglEventButton>;
+/// @copydoc PuglButtonEvent
+using ButtonPressEvent = Event<PUGL_BUTTON_PRESS, PuglButtonEvent>;
-/// @copydoc PuglEventButton
-using ButtonReleaseEvent = Event<PUGL_BUTTON_RELEASE, PuglEventButton>;
+/// @copydoc PuglButtonEvent
+using ButtonReleaseEvent = Event<PUGL_BUTTON_RELEASE, PuglButtonEvent>;
-/// @copydoc PuglEventMotion
-using MotionEvent = Event<PUGL_MOTION, PuglEventMotion>;
+/// @copydoc PuglMotionEvent
+using MotionEvent = Event<PUGL_MOTION, PuglMotionEvent>;
-/// @copydoc PuglEventScroll
-using ScrollEvent = Event<PUGL_SCROLL, PuglEventScroll>;
+/// @copydoc PuglScrollEvent
+using ScrollEvent = Event<PUGL_SCROLL, PuglScrollEvent>;
-/// @copydoc PuglEventClient
-using ClientEvent = Event<PUGL_CLIENT, PuglEventClient>;
+/// @copydoc PuglClientEvent
+using ClientEvent = Event<PUGL_CLIENT, PuglClientEvent>;
-/// @copydoc PuglEventTimer
-using TimerEvent = Event<PUGL_TIMER, PuglEventTimer>;
+/// @copydoc PuglTimerEvent
+using TimerEvent = Event<PUGL_TIMER, PuglTimerEvent>;
-/// @copydoc PuglEventLoopEnter
-using LoopEnterEvent = Event<PUGL_LOOP_ENTER, PuglEventLoopEnter>;
+/// @copydoc PuglLoopEnterEvent
+using LoopEnterEvent = Event<PUGL_LOOP_ENTER, PuglLoopEnterEvent>;
-/// @copydoc PuglEventLoopLeave
-using LoopLeaveEvent = Event<PUGL_LOOP_LEAVE, PuglEventLoopLeave>;
+/// @copydoc PuglLoopLeaveEvent
+using LoopLeaveEvent = Event<PUGL_LOOP_LEAVE, PuglLoopLeaveEvent>;
/**
@}